package jp.ac.takushoku_u.cs;

/**
* SetValueOutOfBoundsException饹ͤԤݤˡ
* ԤȤǤϰϳꤷ褦ȤȤ򼨤˥ޤ
* @version 1.2
* @author  ͵(Kasajima Hiroshi)
*/
/*
* ǽ 2004ǯ1209
*/

public class SetValueOutOfBoundsException extends IllegalValueException{

/**
* åʤ SetValueOutOfBoundsException ۤޤ
*/
	public SetValueOutOfBoundsException(){
		super();
	}
	
/**
* ꤷܺ٥å SetValueOutOfBoundsException ۤޤ
* @param s ܺ٥å
*/
	public SetValueOutOfBoundsException(String s){
		super(s);
	}
}